@@ -41,8 +41,6 @@ simde_float32x2_t
 simde_vmax_f32(simde_float32x2_t a, simde_float32x2_t b) {
   #if defined(SIMDE_ARM_NEON_A32V7_NATIVE)
     return vmax_f32(a, b);
-  #elif SIMDE_NATURAL_VECTOR_SIZE > 0
-    return simde_vbsl_f32(simde_vcgt_f32(a, b), a, b);
   #else
     simde_float32x2_private
       r_,
@@ -51,7 +49,11 @@ simde_vmax_f32(simde_float32x2_t a, simde_float32x2_t b) {
 
     SIMDE_VECTORIZE
     for (size_t i = 0 ; i < (sizeof(r_.values) / sizeof(r_.values[0])) ; i++) {
-      r_.values[i] = (a_.values[i] > b_.values[i]) ? a_.values[i] : b_.values[i];
+      #if !defined(SIMDE_FAST_NANS)
+        r_.values[i] = (a_.values[i] >= b_.values[i]) ? a_.values[i] : ((a_.values[i] < b_.values[i]) ? b_.values[i] : SIMDE_MATH_NANF);
+      #else
+        r_.values[i] = (a_.values[i] > b_.values[i]) ? a_.values[i] : b_.values[i];
+      #endif
     }
 
     return simde_float32x2_from_private(r_);
@@ -67,8 +69,6 @@ simde_float64x1_t
 simde_vmax_f64(simde_float64x1_t a, simde_float64x1_t b) {
   #if defined(SIMDE_ARM_NEON_A64V8_NATIVE)
     return vmax_f64(a, b);
-  #elif SIMDE_NATURAL_VECTOR_SIZE > 0
-    return simde_vbsl_f64(simde_vcgt_f64(a, b), a, b);
   #else
     simde_float64x1_private
       r_,
@@ -77,7 +77,11 @@ simde_vmax_f64(simde_float64x1_t a, simde_float64x1_t b) {
 
     SIMDE_VECTORIZE
     for (size_t i = 0 ; i < (sizeof(r_.values) / sizeof(r_.values[0])) ; i++) {
-      r_.values[i] = (a_.values[i] > b_.values[i]) ? a_.values[i] : b_.values[i];
+      #if !defined(SIMDE_FAST_NANS)
+        r_.values[i] = (a_.values[i] >= b_.values[i]) ? a_.values[i] : ((a_.values[i] < b_.values[i]) ? b_.values[i] : SIMDE_MATH_NAN);
+      #else
+        r_.values[i] = (a_.values[i] > b_.values[i]) ? a_.values[i] : b_.values[i];
+      #endif
     }
 
     return simde_float64x1_from_private(r_);
@@ -290,13 +294,19 @@ simde_vmaxq_f32(simde_float32x4_t a, simde_float32x4_t b) {
   #if defined(SIMDE_ARM_NEON_A32V7_NATIVE)
     return vmaxq_f32(a, b);
   #elif defined(SIMDE_X86_SSE_NATIVE)
-    return _mm_max_ps(a, b);
-  #elif defined(SIMDE_POWER_ALTIVEC_P6_NATIVE)
+    #if !defined(SIMDE_FAST_NANS)
+      __m128 nan_mask = _mm_cmpunord_ps(a, b);
+      __m128 res = _mm_max_ps(a, b);
+      res = _mm_andnot_ps(nan_mask, res);
+      res = _mm_or_ps(res, _mm_and_ps(_mm_set1_ps(SIMDE_MATH_NANF), nan_mask));
+      return res;
+    #else
+      return _mm_max_ps(a, b);
+    #endif
+  #elif defined(SIMDE_POWER_ALTIVEC_P6_NATIVE) && defined(SIMDE_FAST_NANS)
     return vec_max(a, b);
   #elif defined(SIMDE_WASM_SIMD128_NATIVE)
     return wasm_f32x4_max(a, b);
-  #elif SIMDE_NATURAL_VECTOR_SIZE > 0
-    return simde_vbslq_f32(simde_vcgtq_f32(a, b), a, b);
   #else
     simde_float32x4_private
       r_,
@@ -305,7 +315,11 @@ simde_vmaxq_f32(simde_float32x4_t a, simde_float32x4_t b) {
 
     SIMDE_VECTORIZE
     for (size_t i = 0 ; i < (sizeof(r_.values) / sizeof(r_.values[0])) ; i++) {
-      r_.values[i] = (a_.values[i] > b_.values[i]) ? a_.values[i] : b_.values[i];
+      #if !defined(SIMDE_FAST_NANS)
+        r_.values[i] = (a_.values[i] >= b_.values[i]) ? a_.values[i] : ((a_.values[i] < b_.values[i]) ? b_.values[i] : SIMDE_MATH_NANF);
+      #else
+        r_.values[i] = (a_.values[i] > b_.values[i]) ? a_.values[i] : b_.values[i];
+      #endif
     }
 
     return simde_float32x4_from_private(r_);
@@ -322,13 +336,19 @@ simde_vmaxq_f64(simde_float64x2_t a, simde_float64x2_t b) {
   #if defined(SIMDE_ARM_NEON_A64V8_NATIVE)
     return vmaxq_f64(a, b);
   #elif defined(SIMDE_X86_SSE2_NATIVE)
-    return _mm_max_pd(a, b);
-  #elif defined(SIMDE_POWER_ALTIVEC_P7_NATIVE)
+    #if !defined(SIMDE_FAST_NANS)
+      __m128d nan_mask = _mm_cmpunord_pd(a, b);
+      __m128d res = _mm_max_pd(a, b);
+      res = _mm_andnot_pd(nan_mask, res);
+      res = _mm_or_pd(res, _mm_and_pd(_mm_set1_pd(SIMDE_MATH_NAN), nan_mask));
+      return res;
+    #else
+      return _mm_max_pd(a, b);
+    #endif
+  #elif defined(SIMDE_POWER_ALTIVEC_P7_NATIVE) && defined(SIMDE_FAST_NANS)
     return vec_max(a, b);
   #elif defined(SIMDE_WASM_SIMD128_NATIVE)
     return wasm_f64x2_max(a, b);
-  #elif SIMDE_NATURAL_VECTOR_SIZE > 0
-    return simde_vbslq_f64(simde_vcgtq_f64(a, b), a, b);
   #else
     simde_float64x2_private
       r_,
@@ -337,7 +357,11 @@ simde_vmaxq_f64(simde_float64x2_t a, simde_float64x2_t b) {
 
     SIMDE_VECTORIZE
     for (size_t i = 0 ; i < (sizeof(r_.values) / sizeof(r_.values[0])) ; i++) {
-      r_.values[i] = (a_.values[i] > b_.values[i]) ? a_.values[i] : b_.values[i];
+      #if !defined(SIMDE_FAST_NANS)
+        r_.values[i] = (a_.values[i] >= b_.values[i]) ? a_.values[i] : ((a_.values[i] < b_.values[i]) ? b_.values[i] : SIMDE_MATH_NAN);
+      #else
+        r_.values[i] = (a_.values[i] > b_.values[i]) ? a_.values[i] : b_.values[i];
+      #endif
     }
 
     return simde_float64x2_from_private(r_);
