@@ -95,6 +95,10 @@ SIMDE_TEST_DECLARE_SUITE(rev32)
 SIMDE_TEST_DECLARE_SUITE(rev64)
 SIMDE_TEST_DECLARE_SUITE(rhadd)
 SIMDE_TEST_DECLARE_SUITE(rnd)
+SIMDE_TEST_DECLARE_SUITE(rndi)
+SIMDE_TEST_DECLARE_SUITE(rndm)
+SIMDE_TEST_DECLARE_SUITE(rndn)
+SIMDE_TEST_DECLARE_SUITE(rndp)
 SIMDE_TEST_DECLARE_SUITE(rshl)
 SIMDE_TEST_DECLARE_SUITE(rshr_n)
 SIMDE_TEST_DECLARE_SUITE(rsra_n)
