@@ -1,7 +1,7 @@
 #define SIMDE_TEST_X86_AVX512_INSN loadu
 
 #include <test/x86/avx512/test-avx512.h>
-#include <simde/x86/avx512/load.h>
+#include <simde/x86/avx512/loadu.h>
 #include <simde/x86/avx512/set.h>
 
 static int
